@@ -24,11 +24,11 @@ if len(sys.argv) == 1:
     sys.argv.append('--help')
 
 parser = argparse.ArgumentParser(description=__description__)
-parser.add_argument('-v', '--version', dest=version, help="显示版本")
-parser.add_argument('-u', '--url', type=str, help='swagger api地址', required=True)
-parser.add_argument('-U', '--username', default=None, type=str, help='swagger用户名，没有可以不填')
-parser.add_argument('-P', '--password', default=None, type=str, help='swagger密码，没有可以不填')
-parser.add_argument('-p', '--path', default=None, type=str, help='api路径')
+parser.add_argument('-v', '--version', version=version, help="显示版本")
+parser.add_argument('-u', '--url', type=str, help='swagger api地址（必填)', required=True)
+parser.add_argument('-U', '--username', default=None, type=str, help='swagger用户名')
+parser.add_argument('-P', '--password', default=None, type=str, help='swagger密码')
+parser.add_argument('-p', '--path', default=None, type=str, help='api路径，用于单独转换指定api')
 
 
 def main():
